@@ -6,12 +6,12 @@
 """
 __docformat__ = "restructuredtext en"
 
-from cubicweb.selectors import implements
+from cubicweb.selectors import is_instance
 from cubicweb.web.action import Action
 
 class AccountingAction(Action):
     __regid__ = 'accaction'
-    __select__ = implements('Expense')
+    __select__ = is_instance('Expense')
     title = _('generate accounting entries')
 
     def url(self):
